@@ -1,5 +1,3 @@
-library(tinytest)
-
 source("setup.R")
 
 expect_error(detect_raw_enc(NULL))
@@ -11,7 +9,7 @@ expect_equal(detect_raw_enc(charToRaw("Hello")), "ASCII")
 
 x <- as.raw(sample(0:255, 50))
 expect_equal(detect_raw_enc(x), NA_character_)
-expect_warning(detect_raw_enc(x), "Can not handling data.")
+expect_warning(detect_raw_enc(x), "Can not detect encoding.")
 
 if (skip_os()) {
   exit_file("Skip tests on current OS")
